@@ -12,6 +12,8 @@ G_BEGIN_DECLS
 /* --- egg-toolbars-model.h --- */
 #define EGG_TYPE_TB_MODEL_FLAGS egg_tb_model_flags_get_type()
 GType egg_tb_model_flags_get_type (void);
+#define EGG_TYPE_TB_MODEL_NAME_FLAGS egg_tb_model_name_flags_get_type()
+GType egg_tb_model_name_flags_get_type (void);
 G_END_DECLS
 
 #endif /* __EGGTYPEBUILTINS_H__ */
