@@ -21,6 +21,7 @@
 #define __EV_VIEW_H__
 
 #include <gtk/gtkwidget.h>
+#include <gtk/gtklayout.h>
 
 #include "ev-document.h"
 #include "ev-link.h"
@@ -112,6 +113,8 @@ void		ev_view_set_zoom_for_size (EvView         *view,
 		    			   int             height,
 					   int             vsb_width,
 					   int             hsb_height);
+void            ev_view_set_screen_dpi    (EvView         *view,
+					   gdouble         dpi);
 void		ev_view_rotate_left       (EvView         *view);
 void            ev_view_rotate_right      (EvView         *view);
 void            ev_view_set_rotation      (EvView         *view,
@@ -119,8 +122,9 @@ void            ev_view_set_rotation      (EvView         *view,
 int             ev_view_get_rotation      (EvView         *view);
 
 /* Find */
-gboolean	ev_view_can_find_next	  (EvView         *view);
+gboolean        ev_view_can_find_next     (EvView         *view);
 void            ev_view_find_next         (EvView         *view);
+gboolean        ev_view_can_find_previous (EvView         *view);
 void            ev_view_find_previous     (EvView         *view);
 void            ev_view_search_changed    (EvView         *view);
 
@@ -136,10 +140,11 @@ void           ev_view_show_cursor        (EvView         *view);
 void	       ev_view_scroll             (EvView         *view,
 	                                   EvScrollType    scroll,
 					   gboolean        horizontal);
-void	       ev_view_goto_link          (EvView         *view,
+void	       ev_view_handle_link        (EvView         *view,
 					   EvLink         *link);
 gboolean       ev_view_next_page	  (EvView         *view);
 gboolean       ev_view_previous_page	  (EvView         *view);
+gchar*         ev_view_page_label_from_dest (EvView *view, EvLinkDest *dest);
 
 G_END_DECLS
 
